@@ -63,7 +63,7 @@ class TestBronze:
         value = df.collect()
         assert value[0][self.colum_validate_data] == self.value_validate_data
 
-    def initializar_test(self):
+    def restart_enviroment(self):
         self.delta_lake_v1.spark.sql("DROP TABLE {0}.{1}".format(self.delta_lake_v1.database,
                                                                  self.delta_lake_v1.table_name))
         list_file = self.util.list_folder_delta_lake(self.delta_lake_v1.mount_data)
